//!
//!

use std::env;

mod compositions;
mod repositories;
mod services;

#[tokio::main]
async fn main() -> Result<(), Box<dyn std::error::Error>> {
  let url_server_broker = match env::var_os("URL_BROKER") {
    Some(v) => v.into_string().unwrap(),
    None => "".to_string(),
  };
  let queue_server_broker = match env::var_os("QUEUE_BROKER") {
    Some(v) => v.into_string().unwrap(),
    None => "".to_string(),
  };

  let k_secret = match env::var_os("K_SECRET") {
    Some(v) => v.into_string().unwrap(),
    None => "".to_string(),
  };
  let k_username = match env::var_os("K_USERNAME") {
    Some(v) => v.into_string().unwrap(),
    None => "".to_string(),
  };

  let server_broker_opts = nats::asynk::Options::new();
  let connection_server_broker = server_broker_opts.connect(url_server_broker).await?;

  let identity_service = services::identity::service::Service::new(
    connection_server_broker.clone(),
    queue_server_broker.clone(),
    k_secret.clone(),
    k_username.clone(),
  );

  println!("Server service [beteran-api-kgon-server-service] is started");

  futures::try_join!(identity_service.subscribe(),)?;

  Ok(())
}
